import { HttpClient } from '@angular/common/http';
import { Inject, Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { DwSystemConfigService } from '@webdpt/framework/config';
import { DW_AUTH_TOKEN } from '@webdpt/framework/auth';

@Injectable({ providedIn: 'root' })
export class CommonService {
  atdmUrl: string;
  bpmUrl: string;
  atmcUrl: any;
  frcUrl: any;
  eocUrl: any;
  themeMapUrl: any;
  pageData: any;
  // 记录机制的content参数
  content: any;
  uibotUrl: string;
  constructor(
    @Inject(DW_AUTH_TOKEN) protected authToken: any,
    private http: HttpClient,
    private configService: DwSystemConfigService
  ) {
    this.configService.get('atdmUrl').subscribe((url: string): void => {
      this.atdmUrl = url;
    });
    this.configService.get('bpmUrl').subscribe((url): void => {
      this.bpmUrl = url;
    });
    this.configService.get('atmcUrl').subscribe((url): void => {
      this.atmcUrl = url;
    });
    this.configService.get('frcUrl').subscribe((url): void => {
      this.frcUrl = url;
    });
    this.configService.get('eocUrl').subscribe((url): void => {
      this.eocUrl = url;
    });
    this.configService.get('uibotUrl').subscribe((url: string): void => {
      this.uibotUrl = url;
    });
  }
  /**
   * 获取inv_data
   * @param actionId
   * @param params
   * */
  getInvData(actionId: string, params?: any, eoc?: any): Observable<any> {
    const executeContext = this.content?.executeContext;
    const _params = {
      actionId,
      parameter: params,
      businessUnit: eoc || executeContext?.businessUnit,
      executeContext: executeContext, // 传参
    };
    return this.http.post(`${this.atdmUrl}/api/atdm/v1/data/query/by/actionId`, _params, {
      headers: this.getHeader(),
    });
  }

  /**
   * 服务编排-提交数据方法
   * @param params
   * @returns
   */

  atmcSubmit(params: any): Observable<any> {
    const url = `${this.atmcUrl}/api/atmc/v1/action/submit`;
    return this.http.post(url, params, { headers: this.getHeader() });
  }

  getHeader(): any {
    if (this.authToken?.token) {
      return {
        'digi-middleware-auth-user': this.authToken.token,
        token: this.authToken.token,
      };
    }
    return {};
  }

  /**
   * 调用开窗的方法
   * @param executeContext 当前页面的executeContext
   * @param serviceName 调用的服务名称
   * @returns
   */
  getOpenwindowParams(executeContext: any, serviceName: string): any {
    return new Promise((resolve, inject) => {
      const params = {
        tmAction: {
          actionId: 'esp_' + serviceName,
          title: '推荐',
          actionParams: [],
          language: {
            title: {
              en_US: 'recommend',
              zh_TW: '推薦',
            },
          },
          type: 'ESP',
          url: 'http://esp.digiwincloud.com.cn/CROSS/RESTful',
          actionResponse: null,
          serviceName: serviceName,
          needProxyToken: null,
          attachActions: null,
          flatData: null,
        },
        executeContext: executeContext,
      };

      const url = `${this.uibotUrl}/api/ai/v1/data/query/action`;
      this.http
        .post(url, params, {
          headers: this.getHeader(),
        })
        .subscribe((res): void => {
          resolve(res);
        });
    });
  }

}
